@@ -107,7 +107,7 @@ class AppflowClient(BaseClient):
         connectorProfileName: str,
         connectorType: ConnectorTypeType,
         connectionMode: ConnectionModeType,
-        connectorProfileConfig: "ConnectorProfileConfigTypeDef",
+        connectorProfileConfig: ConnectorProfileConfigTypeDef,
         kmsArn: str = ...,
         connectorLabel: str = ...
     ) -> CreateConnectorProfileResponseTypeDef:
@@ -123,10 +123,10 @@ class AppflowClient(BaseClient):
         self,
         *,
         flowName: str,
-        triggerConfig: "TriggerConfigTypeDef",
-        sourceFlowConfig: "SourceFlowConfigTypeDef",
-        destinationFlowConfigList: Sequence["DestinationFlowConfigTypeDef"],
-        tasks: Sequence["TaskTypeDef"],
+        triggerConfig: TriggerConfigTypeDef,
+        sourceFlowConfig: SourceFlowConfigTypeDef,
+        destinationFlowConfigList: Sequence[DestinationFlowConfigTypeDef],
+        tasks: Sequence[TaskTypeDef],
         description: str = ...,
         kmsArn: str = ...,
         tags: Mapping[str, str] = ...
@@ -177,7 +177,7 @@ class AppflowClient(BaseClient):
     ) -> DescribeConnectorEntityResponseTypeDef:
         """
         Provides details regarding the entity used with the connector, with a
-        description of the data model for each entity.
+        description of the data model for each field in that entity.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/appflow.html#Appflow.Client.describe_connector_entity)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_appflow/client/#describe_connector_entity)
@@ -296,7 +296,7 @@ class AppflowClient(BaseClient):
         connectorLabel: str = ...,
         description: str = ...,
         connectorProvisioningType: Literal["LAMBDA"] = ...,
-        connectorProvisioningConfig: "ConnectorProvisioningConfigTypeDef" = ...
+        connectorProvisioningConfig: ConnectorProvisioningConfigTypeDef = ...
     ) -> RegisterConnectorResponseTypeDef:
         """
         Registers a new connector with your Amazon Web Services account.
@@ -353,7 +353,7 @@ class AppflowClient(BaseClient):
         *,
         connectorProfileName: str,
         connectionMode: ConnectionModeType,
-        connectorProfileConfig: "ConnectorProfileConfigTypeDef"
+        connectorProfileConfig: ConnectorProfileConfigTypeDef
     ) -> UpdateConnectorProfileResponseTypeDef:
         """
         Updates a given connector profile associated with your account.
@@ -366,10 +366,10 @@ class AppflowClient(BaseClient):
         self,
         *,
         flowName: str,
-        triggerConfig: "TriggerConfigTypeDef",
-        sourceFlowConfig: "SourceFlowConfigTypeDef",
-        destinationFlowConfigList: Sequence["DestinationFlowConfigTypeDef"],
-        tasks: Sequence["TaskTypeDef"],
+        triggerConfig: TriggerConfigTypeDef,
+        sourceFlowConfig: SourceFlowConfigTypeDef,
+        destinationFlowConfigList: Sequence[DestinationFlowConfigTypeDef],
+        tasks: Sequence[TaskTypeDef],
         description: str = ...
     ) -> UpdateFlowResponseTypeDef:
         """
